@@ -11,6 +11,8 @@
 #include <DGuiApplicationHelper>
 #include <QCommandLineParser>
 #include <launcher1adaptor.h>
+#include <QDBusMessage>
+#include <QDBusConnection>
 
 #include <private/qguiapplication_p.h>
 
@@ -188,4 +190,25 @@ void LauncherController::closeAllPopups()
 void LauncherController::setAvoidHide(bool avoidHide)
 {
     m_avoidHide = avoidHide;
-}
\ No newline at end of file
+}
+
+void LauncherController::showHelp()
+{
+    // 由于当前只有调用 “启动器”，才能跳转到帮助文档的启动器目录。使用launcher 以及launchpad等字段，无法跳转到启动器目录。
+    QString helpTitle = "启动器";
+    
+    const QString &dmanInterface = "com.deepin.Manual.Open";
+    QDBusMessage message = QDBusMessage::createMethodCall(dmanInterface, "/com/deepin/Manual/Open", dmanInterface, "OpenTitle");
+    message << "dde" << helpTitle;
+    QDBusConnection::sessionBus().asyncCall(message);
+}
+
+//首次从全屏切换到窗口时候，会出现焦点丢失抖动问题，从而导致启动器窗口不显示，所以采用此方法处理。
+void LauncherController::setCurrentFrameToWindowedFrame()
+{
+    setVisible(false);
+    QTimer::singleShot(100, this, [this]() {
+        setCurrentFrame("WindowedFrame");
+        setVisible(true);
+    });
+}
