@@ -87,6 +87,8 @@ PersonalizationManager::~PersonalizationManager()
 // return if the window is "personalized" right away.
 bool PersonalizationManager::personalizeWindow(QWindow * window, PersonalizationManager::BgState state)
 {
+    Q_UNUSED(window)
+    Q_UNUSED(state)
     // temporary do nothing for now, since TreeLand plans to update the related protocol
     return true;
     // return m_dptr ? m_dptr->personalizeWindow(window, state) : true;
